* {
    font-family: "Open Sans","Helvetica Neue",Helvetica,Arial,sans-serif;
    font-size: 16;
}
body, .zebra-stripe > :nth-child(2n+1), .depth-0 {
    background-color: white;
    padding-bottom: 100px;
}
.consent-title {
    font-size: 24px;
    color: #065683;
}
.pinstripe {
    border-top: 2px solid #0075b4;
}
.logo-container {
    padding-top: 10px;
    width: 70%;
    max-width: 700px;
    min-width: 300px;
    height: auto;
    margin: 0 auto;
}
.consent-container {
    width: 70%;
    max-width: 700px;
    min-width: 300px;
    margin: 0 auto;
}
.consent-input-container {
    position: absolute;
    border: solid 1px #a0a0a0;
    border-radius: 10px;
    position: relative;
    padding: 25px;
}
.agreement-text {
    overflow: hidden;
}
.consent-agreement-button {
    color: #f2f8fb;
    background-color: #0075B4;
    border-color: transparent;
    height: auto;
    width: 33%;
    font-size: 18;
    padding: 5px 2px;
    max-width: 180px;
    min-width: 125px;
    border-radius: 5px;
}
.consent-agreement-button:hover {
    background-color: #065683;
}
.consent-agreement-button:focus {
    background-color: #065683;
}
.consent-agreement-button:active {
    background-color: #0075B4;
}
.consent-agreement-button:disabled {
    background-color: #a0a0a0;
    color: #d9d9d9;
}
.consent-policy-dropdown-bar {
    text-align: left;
    background-color: #f2f8fb;
    height: 60px;
    border: none;
    width: 100%;
}
.consent-policy-dropdown-bar:hover {
    font-weight: bold;
}
.consent-policy-dropdown-bar:focus {
    font-weight: bold;
}
.consent-policy-dropdown-bar:active {
    font-weight: bold;
}
.failure-link {
    color: #0075B4;
    font-size: 18;
    display: inline-block;
    text-decoration: underline;
    border: none;
    background-color:rgba(0,0,0,0);
    padding: 5px 2px;
}
.failure-link:hover {
    font-weight: bold;
}
.failure-link:focus {
    font-weight: bold;
}
.dropdown-text {
    font-size: 18px;
    color: #065683;
    line-height: 60px;
    white-space: nowrap;
    padding-left: 2%;
}
.dropdown-icon-container {
    float: right;
    padding-right: 10%;
}
#consent-policy-dropdown-icon-surround {
    font-size: 45px;
    line-height: 60px;
    white-space: nowrap;
    color: white;
}
#consent-policy-dropdown-icon {
    font-size: 21px;
    line-height: 60px;
    white-space: nowrap;
    color: #065683;
}
.consent-policy {
    padding-top: 2%;
    padding-left: 3%;
    padding-right: 3%;
}
h1 {
    color: #0075B4;
}

.modal {
    display: none; /* Hidden by default */
    position: fixed; /* Stay in place */
    z-index: 1; /* Sit on top */
    left: -10%;
    top: -10%;
    width: 120%; /* Full width */
    height: 120%; /* Full height */
    overflow: auto; /* Enable scroll if needed */
    background-color: rgb(0,0,0); /* Fallback color */
    background-color: rgba(0,0,0,0.6); /* Black w/ opacity */
}

.modal-close-button {
    position: absolute;
    top: -27;
    right: 3;
    color: white;
    font-size: 1.5em;
    border: none;
    background-color:rgba(0,0,0,0);
}

.modal-close-button:hover {
    font-size: 1.8em;
    top: -30;
    right: 0;
}

.modal-close-button:focus {
    font-size: 1.8em;
    top: -30;
    right: 0;
}

.modal-content {
    position: fixed;
    top: 50%;
    left: 50%;
    right: auto;
    bottom: auto;
    transform: translate(-50%, -50%);
    background-color: #f5f5f5;
    margin: auto;
    padding: 20px;
    width: 80%;
    max-width: 450px;
    max-height: 300px;
    min-width: 300px;
    border-top: 30px solid #0075B4;
}

h2#modal-header-text {
    font-weight: bold;
    font-size: 18;
}

.data-consent-checkbox {
    float: left;
    margin-top: 4px;
    margin-right: 10px;
}
